A dataset containing digitized survival data from a clinical trial.
A data frame with three variables
- time
A numeric vector representing the survival time.
- event
A numeric vector indicating the event status (1 = event, 0 = censored).
- arm
A factor or character vector for the treatment arm.
- id
Patient id