Skip to contents

Displays a formatted summary of the disaggregated and final scores.

Displays a formatted summary of the disaggregated and final scores.

Usage

# S3 method for bayes_summary
print(x, ...)

# S3 method for bayes_summary
print(x, ...)

Arguments

x

An object of class 'bayes_summary'.

...

further arguments passed to or from other methods.