Skip to contents

A dataset containing digitized survival data from a clinical trial.

Usage

spotlight

Format

A data frame with three variables

time

A numeric vector representing the survival time.

event

A numeric vector indicating the event status (1 = event, 0 = censored).

id

Patient id

arm

A factor or character vector for the treatment arm.