Skip to contents

A dataset containing digitized survival data from a clinical trial.

A dataset containing digitized survival data from a clinical trial.

Usage

toga

toga

Format

A data frame with three variables

time

A numeric vector representing the survival time.

event

A numeric vector indicating the event status (1 = event, 0 = censored).

arm

A factor or character vector for the treatment arm.

id

A unique identifier for each subject.

group2

An additional grouping variable.

Intercept

A numeric vector for the intercept term.

A data frame with three variables

time

A numeric vector representing the survival time.

event

A numeric vector indicating the event status (1 = event, 0 = censored).

arm

A factor or character vector for the treatment arm.

id

A unique identifier for each subject.

group2

An additional grouping variable.

Intercept

A numeric vector for the intercept term.