Calculate the ESMO-MCBS v2.0 Score (Guided by Objective)
Source:R/esmo_mcbs.R
calculate_esmo_mcbs.RdCalculates the ESMO-MCBS v2.0 score based on a primary study objective. The function first requires the user to specify the study's main goal, and then uses the corresponding arguments to apply the correct ESMO form logic.