Print method for bayes_summary objects
Source:R/bayescores.R, R/plot_final_utility_density.R
print.bayes_summary.RdDisplays a formatted summary of the disaggregated and final scores.
Displays a formatted summary of the disaggregated and final scores.